==> gwisp-0.0.34.tgz: package/lib/controller/region.js <==
// dependency modules
const express = require('express')
const validator = require('validator')
const RegionRepository = require('../repository/region')

// create region router
// params
// - db <connection>: instance of mongoose connection
// return express router
module.exports = function (db) {
  var repository = new RegionRepository(db)
  var router = express.Router()

  router.route('/')
  .get(function (req, res) {
    if (req.query.pageSize && !validator.isInt(req.query.pageSize)) {
      res.status(422).json({
        message: 'page index must be integer'
      })
      return
    }

    if (req.query.pageSize && !validator.isInt(req.query.pageIndex)) {
      res.status(422).json({
        message: 'page size must be integer'
      })
      return
    }

    var selector = {
      pageSize: req.query.pageSize || 16,
      pageIndex: req.query.pageIndex || 1
    }

    repository.search(null, selector, function (error, items) {
      if (error) {
        res.status(500).json(error)
        return
      }
      if (items.length === 0) {
        res.status(404).json({
          message: 'not found region'
        })
        return
      }

      res.json(items)
    })
  })

  router.route('/:id')
  .get(function (req, res) {
    if (!/^[a-z]{2}$/.test(req.params.id)) {
      res.status(422).json({
        message: 'id must be two lowercase characters'
      })
      return
    }

    repository.findById(req.params.id, function (err, item) {
      if (err) {
        res.status(500).json(err)
        return
      }

      if (item.length === 0) {
        res.status(404).json({
          message: 'not found region'
        })
        return
      }

      res.json(item[0])
    })
  })

  router.route('/search/:keyword/size/:pageSize/index/:pageIndex')
  .get(function (req, res) {
    var selector = {
      pageIndex: Number(req.params.pageIndex),
      pageSize: Number(req.params.pageSize)
    }
    repository.search(req.params.keyword, selector, function (error, items) {
      if (error) {
        res.json(error)
        return
      }

      res.json(items)
    })
  })

  return router
}

==> gwisp-0.0.38.tgz: package/lib/controller/region.js <==
// dependency modules
const express = require('express')
const validator = require('validator')
const RegionRepository = require('../repository/region')

// create region router
// params
// - db <connection>: instance of mongoose connection
// return express router
module.exports = function (db) {
  var repository = new RegionRepository(db)
  var router = express.Router()

  router.route('/')
  .get(function (req, res) {
    if (typeof (req.query.pageSize) === 'string') {
      if (!validator.isInt(req.query.pageSize)) {
        return res.status(422).json({
          message: 'page index must be integer'
        })
      }
    }

    if (typeof (req.query.pageIndex) === 'string') {
      if (!validator.isInt(req.query.pageIndex)) {
        return res.status(422).json({
          message: 'page size must be integer'
        })
      }
    }

    var selector = {
      pageSize: Number(req.query.pageSize) || 16,
      pageIndex: Number(req.query.pageIndex) || 1
    }

    repository.search(null, selector, function (err, items) {
      if (err) return res.status(500).json(err)
      if (items.length === 0) {
        return res.status(404).json({
          message: 'not found region'
        })
      }

      res.json(items)
    })
  })

  router.route('/:id')
  .get(function (req, res) {
    if (!/^[a-z]{2}$/.test(req.params.id)) {
      res.status(422).json({
        message: 'id must be two lowercase characters'
      })
      return
    }

    repository.findById(req.params.id, function (err, item) {
      if (err) {
        res.status(500).json(err)
        return
      }

      if (item.length === 0) {
        res.status(404).json({
          message: 'not found region'
        })
        return
      }

      res.json(item[0])
    })
  })

  router.route('/search/:keyword/size/:pageSize/index/:pageIndex')
  .get(function (req, res) {
    var selector = {
      pageIndex: Number(req.params.pageIndex),
      pageSize: Number(req.params.pageSize)
    }

    repository.search(req.params.keyword, selector, function (err, items) {
      if (err) return res.json(err)

      res.json(items)
    })
  })

  return router
}
